@@ -12,7 +12,7 @@ def ma1x(data:pandas.DataFrame):
     :param data:
     :return:
     """
-    df = data
+    df = data.copy()
     OPEN = df['open']
     CLOSE = df['close']
     HIGH = df['high']
